@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #define _POSIX_SOURCE
@@ -24,6 +24,7 @@
 #include "uconfig.h"
 #include "contact_list.h"
 #include "transport.h"
+#include "tls.h"
 #include "user_iface.h"
 #include "uconfig.h"
 #include "misc.h"
@@ -33,11 +34,13 @@ static void finish (int sig);
 int
 main (int argc, char **argv)
 {
+	contact_t *contact;
+
 	signal (SIGPIPE, SIG_IGN);
 	dmx_signal (SIGINT, finish);
 	dmx_signal (SIGTERM, finish);
 	setlocale (LC_ALL, "");
-	
+
 	CHECK_OK (ui_init ());
 
 	ui_output_info ("\\b\\3" PACKAGE_STRING);
@@ -47,6 +50,15 @@ main (int argc, char **argv)
 	ui_output_info ("\\bType \"/help\" to access online help.");
 	ui_output_info ("");
 
+	if (get_encoding() != OK) {
+		ui_output_err ("");
+		ui_output_err ("Warning: I'll be unable to make charset "
+		               "conversion when sending and/or receiving text. "
+		               "You should check your iconv and locale "
+		               "configuration.");
+		ui_output_err ("");
+	}
+
 	/* TODO: check return val for these? leave or continue? */
 	check_dir (".ipchat");
 	check_dir (".ipchat/log");
@@ -66,12 +78,19 @@ main (int argc, char **argv)
 	}
 #endif
 
+	tls_init ();
 	tr_init_resolver ();
 	tr_init_server ();
 	tr_init_checker ();
 
 	dmx_main_loop ();
 
+	for (contact = contacts; contact; contact = contact->next) {
+		if (contact->state.cn_state != CS_OFFLINE) {
+			tr_disconnect (contact);
+		}
+	}
+	tls_finish ();
 	ui_finish ();
 	dmx_cleanup ();
 
