@@ -13,13 +13,14 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #ifndef MISC_H
 #define MISC_H
 
 #include <unistd.h>
+#include <wchar.h>
 #include "common.h"
 
 #define ERR_C (ERR_LOCAL -1)
@@ -34,5 +35,10 @@ extern int read_tag (int fd, char *src, char *name, char *buff, size_t size);
 extern int write_tag (int fd, char *name, char *buff, size_t tabs);
 extern int check_dir (char *dirname);
 extern char *ipv4_to_string (ip_t ip);
+int utf8_encode (const char *src, size_t mlen, char *utf8s, size_t utf8smlen);
+char * utf8_wencode (const wchar_t *src);
+int utf8_decode (const char *src, size_t mlen, char *dest, size_t destmlen);
+wchar_t * utf8_wdecode (const char *src);
+int get_encoding (void);
 
 #endif
