@@ -75,8 +75,8 @@ extern void * pq_get(prio_t,pqueue *);
 extern void * pq_del_func(void*,pqueue*);
 extern void * pq_get_func(void*,pqueue*);
 extern void * pq_del_ptr(void*,pqueue*);
-extern pq_chpri_func(void*,prio_t,pqueue*); 
-extern pq_chpri_ptr(void*,prio_t,pqueue*); 
+extern int pq_chpri_func(void*,prio_t,pqueue*);
+extern int pq_chpri_ptr(void*,prio_t,pqueue*);
 extern int pq_delete(pqueue*);
 
 #endif /* PQUEUE_H */
