@@ -1,5 +1,5 @@
-/* protocol.c -- understands and generates messages sent over the network
-   Copyright (C) 2004 Maximiliano Pin
+/* protocol.c -- decodes and generates messages sent over the network
+   Copyright (C) 2004-2020 Maximiliano Pin
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
 #include "demux.h"
 #include "misc.h"
 #include "log.h"
+#include "tls.h"
 
 /* Header of sent and received messages. */
 /* ATTENTION: Changing this struct requires revision of hton_header(),
@@ -131,6 +132,7 @@ pr_msg_received (contact_t *contact, const BYTE *msg, int len)
 	const BYTE *payload;
 	int pl_size;
 	int r;
+	struct hdr_hello hello;
 
 	CHECK_J (len >= sizeof(header.type), small_size);
 	type = *(uint16_t *)msg;
@@ -147,7 +149,8 @@ pr_msg_received (contact_t *contact, const BYTE *msg, int len)
 	switch (type) {
 
 		case MSG_HELLO:
-			r = received_hello (contact, &header.c.hello,
+			memcpy (&hello, &header.c.hello, sizeof (hello));
+			r = received_hello (contact, &hello,
 			                    (const char *)payload, pl_size);
 			break;
 
