@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #ifndef PROTOCOL_H
@@ -24,7 +24,7 @@
 
 /* Protocol version. Changes when the program cannot communicate with
    older ipchat's anymore. It's sent in HELLO messages. */
-#define PROTOCOL_VERSION 1
+#define PROTOCOL_VERSION 2
 
 extern void pr_send_text (contact_t *contact, const char *txt);
 extern void pr_send_hello (contact_t *contact);
