@@ -1,4 +1,4 @@
-/* tcp.h -- wrapper to simplify the use of TCP sockets
+/* tcp.c -- wrapper to simplify the use of TCP sockets
    Copyright (C) 2004 Maximiliano Pin
 
    This program is free software; you can redistribute it and/or
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #define _POSIX_SOURCE
